@@ -33,6 +33,9 @@
 #include <QtNetwork/qnetworkrequest.h>
 #include <QtNetwork/qpassworddigestor.h>
 #include <QtNetwork/qssl.h>
+#if QT_CONFIG(networkinterface)
+#include <QtNetwork/qnetworkinterface.h>
+#endif
 #if QT_CONFIG(ssl)
 #include <QtNetwork/qocspresponse.h>
 #include <QtNetwork/qsslcertificate.h>
@@ -41,9 +44,6 @@
 #include <QtNetwork/qsslerror.h>
 #include <QtNetwork/qsslsocket.h>
 #endif
-#ifndef QT_NO_NETWORKINTERFACE
-#include <QtNetwork/qnetworkinterface.h>
-#endif
 
 QT_BEGIN_NAMESPACE
 class QAbstractNetworkCache;
@@ -365,42 +365,41 @@ extern SbkConverter **SbkPySide6_QtNetworkTypeConverters;
 // Converter indices
 enum [[deprecated]] : int {
     SBK_QTNETWORK_QLIST_INT_IDX                              = 0, // QList<int>
-    SBK_QTNETWORK_QLIST_QSSLCERTIFICATE_IDX                  = 2, // QList<QSslCertificate>
-    SBK_QTNETWORK_QLIST_QBYTEARRAY_IDX                       = 4, // QList<QByteArray>
-    SBK_QTNETWORK_QMAP_QBYTEARRAY_QVARIANT_IDX               = 6, // QMap<QByteArray,QVariant>
-    SBK_QTNETWORK_QLIST_QSSLCIPHER_IDX                       = 8, // QList<QSslCipher>
-    SBK_QTNETWORK_QLIST_QSSLELLIPTICCURVE_IDX                = 10, // QList<QSslEllipticCurve>
-    SBK_QTNETWORK_QLIST_QNETWORKPROXY_IDX                    = 12, // QList<QNetworkProxy>
-    SBK_QTNETWORK_QLIST_QNETWORKADDRESSENTRY_IDX             = 14, // QList<QNetworkAddressEntry>
-    SBK_QTNETWORK_QLIST_QHOSTADDRESS_IDX                     = 16, // QList<QHostAddress>
-    SBK_QTNETWORK_QLIST_QNETWORKINTERFACE_IDX                = 18, // QList<QNetworkInterface>
-    SBK_QTNETWORK_QHASH_QNETWORKREQUEST_ATTRIBUTE_QVARIANT_IDX = 20, // QHash<QNetworkRequest::Attribute,QVariant>
-    SBK_QTNETWORK_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX         = 22, // std::pair<QByteArray,QByteArray>
-    SBK_QTNETWORK_QLIST_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX   = 24, // QList<std::pair<QByteArray,QByteArray>>
-    SBK_QTNETWORK_QMULTIHASH_QBYTEARRAY_QBYTEARRAY_IDX       = 26, // QMultiHash<QByteArray,QByteArray>
-    SBK_QTNETWORK_QMULTIMAP_QBYTEARRAY_QBYTEARRAY_IDX        = 28, // QMultiMap<QByteArray,QByteArray>
-    SBK_QTNETWORK_QHASH_QSTRING_QVARIANT_IDX                 = 30, // QHash<QString,QVariant>
-    SBK_QTNETWORK_QLIST_QOBJECTPTR_IDX                       = 32, // QList<QObject*>
-    SBK_QTNETWORK_QMAP_QSTRING_QVARIANT_IDX                  = 34, // QMap<QString,QVariant>
-    SBK_QTNETWORK_QLIST_QNETWORKCOOKIE_IDX                   = 36, // QList<QNetworkCookie>
-    SBK_QTNETWORK_QLIST_QHSTSPOLICY_IDX                      = 38, // QList<QHstsPolicy>
-    SBK_QTNETWORK_QLIST_QSSLERROR_IDX                        = 40, // QList<QSslError>
-    SBK_QTNETWORK_QLIST_QDNSDOMAINNAMERECORD_IDX             = 42, // QList<QDnsDomainNameRecord>
-    SBK_QTNETWORK_QLIST_QDNSHOSTADDRESSRECORD_IDX            = 44, // QList<QDnsHostAddressRecord>
-    SBK_QTNETWORK_QLIST_QDNSMAILEXCHANGERECORD_IDX           = 46, // QList<QDnsMailExchangeRecord>
-    SBK_QTNETWORK_QLIST_QDNSSERVICERECORD_IDX                = 48, // QList<QDnsServiceRecord>
-    SBK_QTNETWORK_QLIST_QDNSTEXTRECORD_IDX                   = 50, // QList<QDnsTextRecord>
-    SBK_QTNETWORK_QLIST_QDNSTLSASSOCIATIONRECORD_IDX         = 52, // QList<QDnsTlsAssociationRecord>
-    SBK_QTNETWORK_STD_PAIR_QHOSTADDRESS_INT_IDX              = 54, // std::pair<QHostAddress,int>
-    SBK_QTNETWORK_QLIST_QSTRING_IDX                          = 56, // QList<QString>
-    SBK_QTNETWORK_QLIST_QSSL_IMPLEMENTEDCLASS_IDX            = 58, // QList<QSsl::ImplementedClass>
-    SBK_QTNETWORK_QLIST_QOCSPRESPONSE_IDX                    = 60, // QList<QOcspResponse>
-    SBK_QTNETWORK_QLIST_QSSL_SUPPORTEDFEATURE_IDX            = 62, // QList<QSsl::SupportedFeature>
-    SBK_QTNETWORK_QLIST_QSSL_SSLPROTOCOL_IDX                 = 64, // QList<QSsl::SslProtocol>
-    SBK_QTNETWORK_QLIST_QSSLCERTIFICATEEXTENSION_IDX         = 66, // QList<QSslCertificateExtension>
-    SBK_QTNETWORK_QMULTIMAP_QSSL_ALTERNATIVENAMEENTRYTYPE_QSTRING_IDX = 68, // QMultiMap<QSsl::AlternativeNameEntryType,QString>
-    SBK_QTNETWORK_QLIST_QVARIANT_IDX                         = 70, // QList<QVariant>
-    SBK_QTNETWORK_CONVERTERS_IDX_COUNT                       = 72,
+    SBK_QTNETWORK_QLIST_QSSLCERTIFICATE_IDX                  = 1, // QList<QSslCertificate>
+    SBK_QTNETWORK_QLIST_QBYTEARRAY_IDX                       = 2, // QList<QByteArray>
+    SBK_QTNETWORK_QMAP_QBYTEARRAY_QVARIANT_IDX               = 3, // QMap<QByteArray,QVariant>
+    SBK_QTNETWORK_QLIST_QSSLCIPHER_IDX                       = 4, // QList<QSslCipher>
+    SBK_QTNETWORK_QLIST_QSSLELLIPTICCURVE_IDX                = 5, // QList<QSslEllipticCurve>
+    SBK_QTNETWORK_QLIST_QNETWORKPROXY_IDX                    = 6, // QList<QNetworkProxy>
+    SBK_QTNETWORK_QLIST_QNETWORKADDRESSENTRY_IDX             = 7, // QList<QNetworkAddressEntry>
+    SBK_QTNETWORK_QLIST_QHOSTADDRESS_IDX                     = 8, // QList<QHostAddress>
+    SBK_QTNETWORK_QLIST_QNETWORKINTERFACE_IDX                = 9, // QList<QNetworkInterface>
+    SBK_QTNETWORK_QHASH_QNETWORKREQUEST_ATTRIBUTE_QVARIANT_IDX = 10, // QHash<QNetworkRequest::Attribute,QVariant>
+    SBK_QTNETWORK_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX         = 11, // std::pair<QByteArray,QByteArray>
+    SBK_QTNETWORK_QLIST_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX   = 12, // QList<std::pair<QByteArray,QByteArray>>
+    SBK_QTNETWORK_QMULTIHASH_QBYTEARRAY_QBYTEARRAY_IDX       = 13, // QMultiHash<QByteArray,QByteArray>
+    SBK_QTNETWORK_QMULTIMAP_QBYTEARRAY_QBYTEARRAY_IDX        = 14, // QMultiMap<QByteArray,QByteArray>
+    SBK_QTNETWORK_QHASH_QSTRING_QVARIANT_IDX                 = 15, // QHash<QString,QVariant>
+    SBK_QTNETWORK_QMAP_QSTRING_QVARIANT_IDX                  = 16, // QMap<QString,QVariant>
+    SBK_QTNETWORK_QLIST_QNETWORKCOOKIE_IDX                   = 17, // QList<QNetworkCookie>
+    SBK_QTNETWORK_QLIST_QHSTSPOLICY_IDX                      = 18, // QList<QHstsPolicy>
+    SBK_QTNETWORK_QLIST_QSSLERROR_IDX                        = 19, // QList<QSslError>
+    SBK_QTNETWORK_QLIST_QDNSDOMAINNAMERECORD_IDX             = 20, // QList<QDnsDomainNameRecord>
+    SBK_QTNETWORK_QLIST_QDNSHOSTADDRESSRECORD_IDX            = 21, // QList<QDnsHostAddressRecord>
+    SBK_QTNETWORK_QLIST_QDNSMAILEXCHANGERECORD_IDX           = 22, // QList<QDnsMailExchangeRecord>
+    SBK_QTNETWORK_QLIST_QDNSSERVICERECORD_IDX                = 23, // QList<QDnsServiceRecord>
+    SBK_QTNETWORK_QLIST_QDNSTEXTRECORD_IDX                   = 24, // QList<QDnsTextRecord>
+    SBK_QTNETWORK_QLIST_QDNSTLSASSOCIATIONRECORD_IDX         = 25, // QList<QDnsTlsAssociationRecord>
+    SBK_QTNETWORK_STD_PAIR_QHOSTADDRESS_INT_IDX              = 26, // std::pair<QHostAddress,int>
+    SBK_QTNETWORK_QLIST_QSTRING_IDX                          = 27, // QList<QString>
+    SBK_QTNETWORK_QLIST_QSSL_IMPLEMENTEDCLASS_IDX            = 28, // QList<QSsl::ImplementedClass>
+    SBK_QTNETWORK_QLIST_QOCSPRESPONSE_IDX                    = 29, // QList<QOcspResponse>
+    SBK_QTNETWORK_QLIST_QSSL_SUPPORTEDFEATURE_IDX            = 30, // QList<QSsl::SupportedFeature>
+    SBK_QTNETWORK_QLIST_QSSL_SSLPROTOCOL_IDX                 = 31, // QList<QSsl::SslProtocol>
+    SBK_QTNETWORK_QLIST_QSSLCERTIFICATEEXTENSION_IDX         = 32, // QList<QSslCertificateExtension>
+    SBK_QTNETWORK_QMULTIMAP_QSSL_ALTERNATIVENAMEENTRYTYPE_QSTRING_IDX = 33, // QMultiMap<QSsl::AlternativeNameEntryType,QString>
+    SBK_QTNETWORK_QLIST_QVARIANT_IDX                         = 34, // QList<QVariant>
+    SBK_QTNETWORK_CONVERTERS_IDX_COUNT                       = 35,
 };
 
 // Converter indices
@@ -421,27 +420,26 @@ enum : int {
     SBK_QtNetwork_QMultiHash_QByteArray_QByteArray_IDX       = 13, // QMultiHash<QByteArray,QByteArray>
     SBK_QtNetwork_QMultiMap_QByteArray_QByteArray_IDX        = 14, // QMultiMap<QByteArray,QByteArray>
     SBK_QtNetwork_QHash_QString_QVariant_IDX                 = 15, // QHash<QString,QVariant>
-    SBK_QtNetwork_QList_QObjectPTR_IDX                       = 16, // QList<QObject*>
-    SBK_QtNetwork_QMap_QString_QVariant_IDX                  = 17, // QMap<QString,QVariant>
-    SBK_QtNetwork_QList_QNetworkCookie_IDX                   = 18, // QList<QNetworkCookie>
-    SBK_QtNetwork_QList_QHstsPolicy_IDX                      = 19, // QList<QHstsPolicy>
-    SBK_QtNetwork_QList_QSslError_IDX                        = 20, // QList<QSslError>
-    SBK_QtNetwork_QList_QDnsDomainNameRecord_IDX             = 21, // QList<QDnsDomainNameRecord>
-    SBK_QtNetwork_QList_QDnsHostAddressRecord_IDX            = 22, // QList<QDnsHostAddressRecord>
-    SBK_QtNetwork_QList_QDnsMailExchangeRecord_IDX           = 23, // QList<QDnsMailExchangeRecord>
-    SBK_QtNetwork_QList_QDnsServiceRecord_IDX                = 24, // QList<QDnsServiceRecord>
-    SBK_QtNetwork_QList_QDnsTextRecord_IDX                   = 25, // QList<QDnsTextRecord>
-    SBK_QtNetwork_QList_QDnsTlsAssociationRecord_IDX         = 26, // QList<QDnsTlsAssociationRecord>
-    SBK_QtNetwork_std_pair_QHostAddress_int_IDX              = 27, // std::pair<QHostAddress,int>
-    SBK_QtNetwork_QList_QString_IDX                          = 28, // QList<QString>
-    SBK_QtNetwork_QList_QSsl_ImplementedClass_IDX            = 29, // QList<QSsl::ImplementedClass>
-    SBK_QtNetwork_QList_QOcspResponse_IDX                    = 30, // QList<QOcspResponse>
-    SBK_QtNetwork_QList_QSsl_SupportedFeature_IDX            = 31, // QList<QSsl::SupportedFeature>
-    SBK_QtNetwork_QList_QSsl_SslProtocol_IDX                 = 32, // QList<QSsl::SslProtocol>
-    SBK_QtNetwork_QList_QSslCertificateExtension_IDX         = 33, // QList<QSslCertificateExtension>
-    SBK_QtNetwork_QMultiMap_QSsl_AlternativeNameEntryType_QString_IDX = 34, // QMultiMap<QSsl::AlternativeNameEntryType,QString>
-    SBK_QtNetwork_QList_QVariant_IDX                         = 35, // QList<QVariant>
-    SBK_QtNetwork_CONVERTERS_IDX_COUNT                       = 36,
+    SBK_QtNetwork_QMap_QString_QVariant_IDX                  = 16, // QMap<QString,QVariant>
+    SBK_QtNetwork_QList_QNetworkCookie_IDX                   = 17, // QList<QNetworkCookie>
+    SBK_QtNetwork_QList_QHstsPolicy_IDX                      = 18, // QList<QHstsPolicy>
+    SBK_QtNetwork_QList_QSslError_IDX                        = 19, // QList<QSslError>
+    SBK_QtNetwork_QList_QDnsDomainNameRecord_IDX             = 20, // QList<QDnsDomainNameRecord>
+    SBK_QtNetwork_QList_QDnsHostAddressRecord_IDX            = 21, // QList<QDnsHostAddressRecord>
+    SBK_QtNetwork_QList_QDnsMailExchangeRecord_IDX           = 22, // QList<QDnsMailExchangeRecord>
+    SBK_QtNetwork_QList_QDnsServiceRecord_IDX                = 23, // QList<QDnsServiceRecord>
+    SBK_QtNetwork_QList_QDnsTextRecord_IDX                   = 24, // QList<QDnsTextRecord>
+    SBK_QtNetwork_QList_QDnsTlsAssociationRecord_IDX         = 25, // QList<QDnsTlsAssociationRecord>
+    SBK_QtNetwork_std_pair_QHostAddress_int_IDX              = 26, // std::pair<QHostAddress,int>
+    SBK_QtNetwork_QList_QString_IDX                          = 27, // QList<QString>
+    SBK_QtNetwork_QList_QSsl_ImplementedClass_IDX            = 28, // QList<QSsl::ImplementedClass>
+    SBK_QtNetwork_QList_QOcspResponse_IDX                    = 29, // QList<QOcspResponse>
+    SBK_QtNetwork_QList_QSsl_SupportedFeature_IDX            = 30, // QList<QSsl::SupportedFeature>
+    SBK_QtNetwork_QList_QSsl_SslProtocol_IDX                 = 31, // QList<QSsl::SslProtocol>
+    SBK_QtNetwork_QList_QSslCertificateExtension_IDX         = 32, // QList<QSslCertificateExtension>
+    SBK_QtNetwork_QMultiMap_QSsl_AlternativeNameEntryType_QString_IDX = 33, // QMultiMap<QSsl::AlternativeNameEntryType,QString>
+    SBK_QtNetwork_QList_QVariant_IDX                         = 34, // QList<QVariant>
+    SBK_QtNetwork_CONVERTERS_IDX_COUNT                       = 35,
 };
 // Macros for type check
 
@@ -513,7 +511,7 @@ template<> inline PyTypeObject *SbkType< ::QFlags<QLocalSocket::SocketOption> >(
 template<> inline PyTypeObject *SbkType< ::QLocalSocket >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QLocalSocket_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkAccessManager::Operation >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_Operation_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkAccessManager >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_IDX]); }
-#ifndef QT_NO_NETWORKINTERFACE
+#if QT_CONFIG(networkinterface)
 template<> inline PyTypeObject *SbkType< ::QNetworkAddressEntry::DnsEligibilityStatus >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_DnsEligibilityStatus_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkAddressEntry >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]); }
 #endif
@@ -529,7 +527,7 @@ template<> inline PyTypeObject *SbkType< ::QNetworkInformation::TransportMedium
 template<> inline PyTypeObject *SbkType< ::QNetworkInformation::Feature >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_Feature_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QFlags<QNetworkInformation::Feature> >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QNetworkInformation_Feature_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkInformation >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]); }
-#ifndef QT_NO_NETWORKINTERFACE
+#if QT_CONFIG(networkinterface)
 template<> inline PyTypeObject *SbkType< ::QNetworkInterface::InterfaceFlag >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_InterfaceFlag_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QFlags<QNetworkInterface::InterfaceFlag> >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QNetworkInterface_InterfaceFlag_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkInterface::InterfaceType >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_InterfaceType_IDX]); }
