@@ -252,20 +252,18 @@ extern SbkConverter **SbkPySide6_QtOpenGLTypeConverters;
 // Converter indices
 enum [[deprecated]] : int {
     SBK_QTOPENGL_QLIST_INT_IDX                               = 0, // QList<int>
-    SBK_QTOPENGL_STD_PAIR_INT_INT_IDX                        = 2, // std::pair<int,int>
-    SBK_QTOPENGL_STD_PAIR_FLOAT_FLOAT_IDX                    = 4, // std::pair<float,float>
-    SBK_QTOPENGL_STD_PAIR_QOPENGLTEXTURE_FILTER_QOPENGLTEXTURE_FILTER_IDX = 6, // std::pair<QOpenGLTexture::Filter,QOpenGLTexture::Filter>
-    SBK_QTOPENGL_QLIST_QSIZE_IDX                             = 8, // QList<QSize>
-    SBK_QTOPENGL_QLIST_UNSIGNEDINT_IDX                       = 10, // QList<unsigned int>
-    SBK_QTOPENGL_QLIST_QOBJECTPTR_IDX                        = 12, // QList<QObject*>
-    SBK_QTOPENGL_QLIST_QBYTEARRAY_IDX                        = 14, // QList<QByteArray>
-    SBK_QTOPENGL_QLIST_FLOAT_IDX                             = 16, // QList<float>
-    SBK_QTOPENGL_QLIST_QOPENGLSHADERPTR_IDX                  = 18, // QList<QOpenGLShader*>
-    SBK_QTOPENGL_QLIST_QOPENGLDEBUGMESSAGE_IDX               = 20, // QList<QOpenGLDebugMessage>
-    SBK_QTOPENGL_QLIST_QVARIANT_IDX                          = 22, // QList<QVariant>
-    SBK_QTOPENGL_QLIST_QSTRING_IDX                           = 24, // QList<QString>
-    SBK_QTOPENGL_QMAP_QSTRING_QVARIANT_IDX                   = 26, // QMap<QString,QVariant>
-    SBK_QTOPENGL_CONVERTERS_IDX_COUNT                        = 28,
+    SBK_QTOPENGL_STD_PAIR_INT_INT_IDX                        = 1, // std::pair<int,int>
+    SBK_QTOPENGL_STD_PAIR_FLOAT_FLOAT_IDX                    = 2, // std::pair<float,float>
+    SBK_QTOPENGL_STD_PAIR_QOPENGLTEXTURE_FILTER_QOPENGLTEXTURE_FILTER_IDX = 3, // std::pair<QOpenGLTexture::Filter,QOpenGLTexture::Filter>
+    SBK_QTOPENGL_QLIST_QSIZE_IDX                             = 4, // QList<QSize>
+    SBK_QTOPENGL_QLIST_UNSIGNEDINT_IDX                       = 5, // QList<unsigned int>
+    SBK_QTOPENGL_QLIST_FLOAT_IDX                             = 6, // QList<float>
+    SBK_QTOPENGL_QLIST_QOPENGLSHADERPTR_IDX                  = 7, // QList<QOpenGLShader*>
+    SBK_QTOPENGL_QLIST_QOPENGLDEBUGMESSAGE_IDX               = 8, // QList<QOpenGLDebugMessage>
+    SBK_QTOPENGL_QLIST_QVARIANT_IDX                          = 9, // QList<QVariant>
+    SBK_QTOPENGL_QLIST_QSTRING_IDX                           = 10, // QList<QString>
+    SBK_QTOPENGL_QMAP_QSTRING_QVARIANT_IDX                   = 11, // QMap<QString,QVariant>
+    SBK_QTOPENGL_CONVERTERS_IDX_COUNT                        = 12,
 };
 
 // Converter indices
@@ -276,15 +274,13 @@ enum : int {
     SBK_QtOpenGL_std_pair_QOpenGLTexture_Filter_QOpenGLTexture_Filter_IDX = 3, // std::pair<QOpenGLTexture::Filter,QOpenGLTexture::Filter>
     SBK_QtOpenGL_QList_QSize_IDX                             = 4, // QList<QSize>
     SBK_QtOpenGL_QList_unsignedint_IDX                       = 5, // QList<unsigned int>
-    SBK_QtOpenGL_QList_QObjectPTR_IDX                        = 6, // QList<QObject*>
-    SBK_QtOpenGL_QList_QByteArray_IDX                        = 7, // QList<QByteArray>
-    SBK_QtOpenGL_QList_float_IDX                             = 8, // QList<float>
-    SBK_QtOpenGL_QList_QOpenGLShaderPTR_IDX                  = 9, // QList<QOpenGLShader*>
-    SBK_QtOpenGL_QList_QOpenGLDebugMessage_IDX               = 10, // QList<QOpenGLDebugMessage>
-    SBK_QtOpenGL_QList_QVariant_IDX                          = 11, // QList<QVariant>
-    SBK_QtOpenGL_QList_QString_IDX                           = 12, // QList<QString>
-    SBK_QtOpenGL_QMap_QString_QVariant_IDX                   = 13, // QMap<QString,QVariant>
-    SBK_QtOpenGL_CONVERTERS_IDX_COUNT                        = 14,
+    SBK_QtOpenGL_QList_float_IDX                             = 6, // QList<float>
+    SBK_QtOpenGL_QList_QOpenGLShaderPTR_IDX                  = 7, // QList<QOpenGLShader*>
+    SBK_QtOpenGL_QList_QOpenGLDebugMessage_IDX               = 8, // QList<QOpenGLDebugMessage>
+    SBK_QtOpenGL_QList_QVariant_IDX                          = 9, // QList<QVariant>
+    SBK_QtOpenGL_QList_QString_IDX                           = 10, // QList<QString>
+    SBK_QtOpenGL_QMap_QString_QVariant_IDX                   = 11, // QMap<QString,QVariant>
+    SBK_QtOpenGL_CONVERTERS_IDX_COUNT                        = 12,
 };
 // Macros for type check
 
