@@ -6,8 +6,8 @@ from types import ModuleType
 
 # __all__ is computed below.
 __pre_all__ = ["QtCore", "QtGui", "QtWidgets", "QtPrintSupport", "QtSql", "QtNetwork", "QtTest", "QtConcurrent", "QtDBus", "QtDesigner", "QtXml", "QtHelp", "QtMultimedia", "QtMultimediaWidgets", "QtOpenGL", "QtOpenGLWidgets", "QtPdf", "QtPdfWidgets", "QtPositioning", "QtLocation", "QtNetworkAuth", "QtNfc", "QtQml", "QtQuick", "QtQuick3D", "QtQuickControls2", "QtQuickTest", "QtQuickWidgets", "QtRemoteObjects", "QtScxml", "QtSensors", "QtSerialPort", "QtSerialBus", "QtStateMachine", "QtTextToSpeech", "QtCharts", "QtSpatialAudio", "QtSvg", "QtSvgWidgets", "QtDataVisualization", "QtGraphs", "QtGraphsWidgets", "QtBluetooth", "QtUiTools", "QtWebChannel", "QtWebEngineCore", "QtWebEngineWidgets", "QtWebEngineQuick", "QtWebSockets", "QtHttpServer", "QtWebView", "Qt3DCore", "Qt3DRender", "Qt3DInput", "Qt3DLogic", "Qt3DAnimation", "Qt3DExtras"]
-__version__ = "6.8.3"
-__version_info__ = (6, 8, 3, "", "")
+__version__ = "6.10.1"
+__version_info__ = (6, 10, 1, "", "")
 
 SKIP_MYPY_TEST = bool("")
 
@@ -64,9 +64,9 @@ def _setupQtDirectories():
         #              setting dictates. There is no longer a difference in path structure.
         global Shiboken
         from shiboken6 import Shiboken
-    except Exception:
+    except Exception as e:
         paths = ', '.join(sys.path)
-        print(f"PySide6/__init__.py: Unable to import Shiboken from {paths}",
+        print(f"PySide6/__init__.py: Unable to import Shiboken from {paths}: {e}",
               file=sys.stderr)
         raise
 
@@ -101,10 +101,13 @@ def _find_all_qt_modules():
 
     # Instead, we use __getattr__ which is supported since Python 3.7
     # and create the __all__ list on demand when needed.
-    location = Path(__file__).resolve().parent
-    files = os.listdir(location)
-    unordered = set(name[: name.find(".")] for name in files if name.startswith("Qt") and (
-                                                                name.endswith((".pyd", ".so"))))
+    unordered = set()
+    pattern = "Qt*.pyd" if sys.platform == "win32" else "Qt*.so"
+    for module in Path(__file__).resolve().parent.glob(pattern):
+        name = module.name[:module.name.find(".")]
+        if name.endswith("_d"):  # Windows debug suffix?
+            name = name[:-2]
+        unordered.add(name)
     ordered_part = __pre_all__
     result = []
     for name in ordered_part:
